@@ -7,9 +7,8 @@
 #  Authors: Revva Konstantin <k.revva@abm-jsc.ru>
 
 
-from detector_connector import DetectorConnector
+from detector_connector import DetectorConnector, DetectorAnalyzeResult
 
-from shift_detector_connector.shift_analyze_result import ShiftAnalyzeResult
 from shift_detector_connector.shift_settings import ShiftSettings
 
 
@@ -20,5 +19,5 @@ class ShiftDetectorConnector(DetectorConnector):
     def __init__(self, config: Config, context: Context):
         super().__init__(config=config,
                          context=context,
-                         detector_analyze_result_type=ShiftAnalyzeResult,
+                         detector_analyze_result_type=DetectorAnalyzeResult,
                          detector_settings_type=ShiftSettings)
